@@ -6,10 +6,9 @@ import logging
 from typing import Dict, Any, List
 
 import click
-from botocore.session import get_session
-from click.types import FuncParamType
-from click import prompt
 from click import confirm
+from click import prompt
+from click.types import FuncParamType
 
 from samcli.commands._utils.options import _space_separated_list_func_type
 from samcli.commands._utils.template import (
@@ -17,6 +16,7 @@ from samcli.commands._utils.template import (
     get_template_artifacts_format,
     get_template_function_resource_ids,
 )
+from samcli.commands.deploy.auth_utils import auth_per_resource
 from samcli.commands.deploy.code_signer_utils import (
     signer_config_per_function,
     extract_profile_name_and_owner_from_existing,
@@ -25,16 +25,17 @@ from samcli.commands.deploy.code_signer_utils import (
 )
 from samcli.commands.deploy.exceptions import GuidedDeployFailedError
 from samcli.commands.deploy.guided_config import GuidedConfig
-from samcli.commands.deploy.auth_utils import auth_per_resource
 from samcli.commands.deploy.utils import sanitize_parameter_overrides
-from samcli.lib.config.samconfig import DEFAULT_ENV, DEFAULT_CONFIG_FILE_NAME
 from samcli.lib.bootstrap.bootstrap import manage_stack
+from samcli.lib.config.samconfig import DEFAULT_ENV, DEFAULT_CONFIG_FILE_NAME
+from samcli.lib.intrinsic_resolver.intrinsics_symbol_table import IntrinsicsSymbolTable
 from samcli.lib.package.ecr_utils import is_ecr_url
 from samcli.lib.package.image_utils import tag_translation, NonLocalImageException, NoImageFoundException
 from samcli.lib.providers.provider import Stack
 from samcli.lib.providers.sam_function_provider import SamFunctionProvider
 from samcli.lib.providers.sam_stack_provider import SamLocalStackProvider
 from samcli.lib.utils.colors import Colored
+from samcli.lib.utils.defaults import get_default_aws_region
 from samcli.lib.utils.packagetype import IMAGE
 
 LOG = logging.getLogger(__name__)
@@ -109,7 +110,7 @@ class GuidedContext:
             The keys of parameters to override, for each key, customers will be asked to provide a value
         """
         default_stack_name = self.stack_name or "sam-app"
-        default_region = self.region or get_session().get_config_variable("region") or "us-east-1"
+        default_region = self.region or get_default_aws_region()
         default_capabilities = self.capabilities[0] or ("CAPABILITY_IAM",)
         default_config_env = self.config_env or DEFAULT_ENV
         default_config_file = self.config_file or DEFAULT_CONFIG_FILE_NAME
@@ -127,11 +128,14 @@ class GuidedContext:
             f"\t{self.start_bold}Stack Name{self.end_bold}", default=default_stack_name, type=click.STRING
         )
         region = prompt(f"\t{self.start_bold}AWS Region{self.end_bold}", default=default_region, type=click.STRING)
+        global_parameter_overrides = {IntrinsicsSymbolTable.AWS_REGION: region}
         input_parameter_overrides = self.prompt_parameters(
             parameter_override_keys, self.parameter_overrides_from_cmdline, self.start_bold, self.end_bold
         )
         stacks, _ = SamLocalStackProvider.get_stacks(
-            self.template_file, parameter_overrides=sanitize_parameter_overrides(input_parameter_overrides)
+            self.template_file,
+            parameter_overrides=sanitize_parameter_overrides(input_parameter_overrides),
+            global_parameter_overrides=global_parameter_overrides,
         )
         image_repositories = self.prompt_image_repository(stacks)
 
@@ -312,7 +316,7 @@ class GuidedContext:
                     if isinstance(self.image_repositories, dict)
                     else "" or self.image_repository,
                 )
-                if not is_ecr_url(image_repositories.get(resource_id)):
+                if resource_id not in image_repositories or not is_ecr_url(str(image_repositories[resource_id])):
                     raise GuidedDeployFailedError(
                         f"Invalid Image Repository ECR URI: {image_repositories.get(resource_id)}"
                     )
