@@ -9,7 +9,7 @@ from enum import Enum
 from pathlib import Path
 from typing import Dict, List, Optional, IO, cast, Tuple, Any
 
-import samcli.lib.utils.osutils as osutils
+from samcli.lib.utils import osutils
 from samcli.lib.providers.provider import Stack, Function
 from samcli.lib.providers.sam_stack_provider import SamLocalStackProvider
 from samcli.lib.utils.async_utils import AsyncContext
@@ -75,6 +75,8 @@ class InvokeContext:
         warm_container_initialization_mode: Optional[str] = None,
         debug_function: Optional[str] = None,
         shutdown: bool = False,
+        container_host: Optional[str] = None,
+        container_host_interface: Optional[str] = None,
     ) -> None:
         """
         Initialize the context
@@ -121,6 +123,10 @@ class InvokeContext:
             option is enabled
         shutdown bool
             Optional. If True, perform a SHUTDOWN event when tearing down containers. Default False.
+        container_host string
+            Optional. Host of locally emulated Lambda container
+        container_host_interface string
+            Optional. Interface that Docker host binds ports to
         """
         self._template_file = template_file
         self._function_identifier = function_identifier
@@ -146,6 +152,9 @@ class InvokeContext:
         self._aws_profile = aws_profile
         self._shutdown = shutdown
 
+        self._container_host = container_host
+        self._container_host_interface = container_host_interface
+
         self._containers_mode = ContainersMode.COLD
         self._containers_initializing_mode = ContainersInitializationMode.LAZY
 
@@ -243,7 +252,9 @@ class InvokeContext:
 
         def initialize_function_container(function: Function) -> None:
             function_config = self.local_lambda_runner.get_invoke_config(function)
-            self.lambda_runtime.run(None, function_config, self._debug_context)
+            self.lambda_runtime.run(
+                None, function_config, self._debug_context, self._container_host, self._container_host_interface
+            )
 
         try:
             async_context = AsyncContext()
@@ -327,6 +338,8 @@ class InvokeContext:
             aws_region=self._aws_region,
             env_vars_values=self._env_vars_value,
             debug_context=self._debug_context,
+            container_host=self._container_host,
+            container_host_interface=self._container_host_interface,
         )
         return self._local_lambda_runner
 
