@@ -1,10 +1,13 @@
 """Parses SAM given a template"""
 import logging
+from typing import Any, Dict, Optional, Tuple, List, cast
 
 from samcli.commands.local.lib.swagger.integration_uri import LambdaUri
+from samcli.lib.providers.provider import Stack
 from samcli.local.apigw.local_apigw_service import Route
 from samcli.commands.local.cli_common.user_exceptions import InvalidSamTemplateException
 from samcli.lib.providers.cfn_base_api_provider import CfnBaseApiProvider
+from samcli.lib.providers.api_collector import ApiCollector
 
 LOG = logging.getLogger(__name__)
 
@@ -31,66 +34,69 @@ class CfnApiProvider(CfnBaseApiProvider):
         APIGATEWAY_V2_STAGE,
     ]
 
-    def extract_resources(self, resources, collector, cwd=None):
+    def extract_resources(self, stacks: List[Stack], collector: ApiCollector, cwd: Optional[str] = None) -> None:
         """
         Extract the Route Object from a given resource and adds it to the RouteCollector.
 
         Parameters
         ----------
-        resources: dict
-            The dictionary containing the different resources within the template
+        stacks: List[Stack]
+            List of stacks apis are extracted from
 
         collector: samcli.lib.providers.api_collector.ApiCollector
             Instance of the API collector that where we will save the API information
 
         cwd : str
             Optional working directory with respect to which we will resolve relative path to Swagger file
-
-        Return
-        -------
-        Returns a list of routes
         """
 
-        for logical_id, resource in resources.items():
-            resource_type = resource.get(CfnBaseApiProvider.RESOURCE_TYPE)
-            if resource_type == CfnApiProvider.APIGATEWAY_RESTAPI:
-                self._extract_cloud_formation_route(logical_id, resource, collector, cwd=cwd)
+        for stack in stacks:
+            resources = stack.resources
+            for logical_id, resource in resources.items():
+                resource_type = resource.get(CfnBaseApiProvider.RESOURCE_TYPE)
+                if resource_type == CfnApiProvider.APIGATEWAY_RESTAPI:
+                    self._extract_cloud_formation_route(stack.stack_path, logical_id, resource, collector, cwd=cwd)
 
-            if resource_type == CfnApiProvider.APIGATEWAY_STAGE:
-                self._extract_cloud_formation_stage(resources, resource, collector)
+                if resource_type == CfnApiProvider.APIGATEWAY_STAGE:
+                    self._extract_cloud_formation_stage(resources, resource, collector)
 
-            if resource_type == CfnApiProvider.APIGATEWAY_METHOD:
-                self._extract_cloud_formation_method(resources, logical_id, resource, collector)
+                if resource_type == CfnApiProvider.APIGATEWAY_METHOD:
+                    self._extract_cloud_formation_method(stack.stack_path, resources, logical_id, resource, collector)
 
-            if resource_type == CfnApiProvider.APIGATEWAY_V2_API:
-                self._extract_cfn_gateway_v2_api(logical_id, resource, collector, cwd=cwd)
+                if resource_type == CfnApiProvider.APIGATEWAY_V2_API:
+                    self._extract_cfn_gateway_v2_api(stack.stack_path, logical_id, resource, collector, cwd=cwd)
 
-            if resource_type == CfnApiProvider.APIGATEWAY_V2_ROUTE:
-                self._extract_cfn_gateway_v2_route(resources, logical_id, resource, collector)
+                if resource_type == CfnApiProvider.APIGATEWAY_V2_ROUTE:
+                    self._extract_cfn_gateway_v2_route(stack.stack_path, resources, logical_id, resource, collector)
 
-            if resource_type == CfnApiProvider.APIGATEWAY_V2_STAGE:
-                self._extract_cfn_gateway_v2_stage(resources, resource, collector)
+                if resource_type == CfnApiProvider.APIGATEWAY_V2_STAGE:
+                    self._extract_cfn_gateway_v2_stage(resources, resource, collector)
 
-        all_apis = []
-        for _, apis in collector:
-            all_apis.extend(apis)
-        return all_apis
-
-    def _extract_cloud_formation_route(self, logical_id, api_resource, collector, cwd=None):
+    @staticmethod
+    def _extract_cloud_formation_route(
+        stack_path: str,
+        logical_id: str,
+        api_resource: Dict[str, Any],
+        collector: ApiCollector,
+        cwd: Optional[str] = None,
+    ) -> None:
         """
         Extract APIs from AWS::ApiGateway::RestApi resource by reading and parsing Swagger documents. The result is
         added to the collector.
 
         Parameters
         ----------
+        stack_path : str
+            Path of the stack the resource is located
+
         logical_id : str
             Logical ID of the resource
-
         api_resource : dict
             Resource definition, including its properties
-
         collector : ApiCollector
             Instance of the API collector that where we will save the API information
+        cwd : Optional[str]
+            An optional string to override the current working directory
         """
         properties = api_resource.get("Properties", {})
         body = properties.get("Body")
@@ -101,10 +107,14 @@ class CfnApiProvider(CfnBaseApiProvider):
             # Swagger is not found anywhere.
             LOG.debug("Skipping resource '%s'. Swagger document not found in Body and BodyS3Location", logical_id)
             return
-        self.extract_swagger_route(logical_id, body, body_s3_location, binary_media, collector, cwd)
+        CfnBaseApiProvider.extract_swagger_route(
+            stack_path, logical_id, body, body_s3_location, binary_media, collector, cwd
+        )
 
     @staticmethod
-    def _extract_cloud_formation_stage(resources, stage_resource, collector):
+    def _extract_cloud_formation_stage(
+        resources: Dict[str, Dict], stage_resource: Dict, collector: ApiCollector
+    ) -> None:
         """
          Extract the stage from AWS::ApiGateway::Stage resource by reading and adds it to the collector.
          Parameters
@@ -136,12 +146,22 @@ class CfnApiProvider(CfnBaseApiProvider):
         collector.stage_name = stage_name
         collector.stage_variables = stage_variables
 
-    def _extract_cloud_formation_method(self, resources, logical_id, method_resource, collector):
+    def _extract_cloud_formation_method(
+        self,
+        stack_path: str,
+        resources: Dict[str, Dict],
+        logical_id: str,
+        method_resource: Dict,
+        collector: ApiCollector,
+    ) -> None:
         """
         Extract APIs from AWS::ApiGateway::Method and work backwards up the tree to resolve and find the true path.
 
         Parameters
         ----------
+        stack_path : str
+            Path of the stack the resource is located
+
         resources: dict
             All Resource definition, including its properties
 
@@ -179,11 +199,21 @@ class CfnApiProvider(CfnBaseApiProvider):
             collector.add_binary_media_types(logical_id, [content_type])
 
         routes = Route(
-            methods=[method], function_name=self._get_integration_function_name(integration), path=resource_path
+            methods=[method],
+            function_name=self._get_integration_function_name(integration),
+            path=resource_path,
+            stack_path=stack_path,
         )
         collector.add_routes(rest_api_id, [routes])
 
-    def _extract_cfn_gateway_v2_api(self, logical_id, api_resource, collector, cwd=None):
+    def _extract_cfn_gateway_v2_api(
+        self,
+        stack_path: str,
+        logical_id: str,
+        api_resource: Dict,
+        collector: ApiCollector,
+        cwd: Optional[str] = None,
+    ) -> None:
         """
         Extract APIs from AWS::ApiGatewayV2::Api resource by reading and parsing Swagger documents. The result is
         added to the collector. If the Swagger documents is not available, it can add a catch-all route based on
@@ -191,14 +221,17 @@ class CfnApiProvider(CfnBaseApiProvider):
 
         Parameters
         ----------
+        stack_path : str
+            Path of the stack the resource is located
+
         logical_id : str
             Logical ID of the resource
-
         api_resource : dict
             Resource definition, including its properties
-
         collector : ApiCollector
             Instance of the API collector that where we will save the API information
+        cwd : Optional[str]
+            An optional string to override the current working directory
         """
         properties = api_resource.get("Properties", {})
         body = properties.get("Body")
@@ -219,19 +252,32 @@ class CfnApiProvider(CfnBaseApiProvider):
                     path=path,
                     function_name=LambdaUri.get_function_name(target),
                     event_type=Route.HTTP,
+                    stack_path=stack_path,
                 )
                 collector.add_routes(logical_id, [routes])
             return
 
-        self.extract_swagger_route(logical_id, body, body_s3_location, None, collector, cwd, Route.HTTP)
+        CfnBaseApiProvider.extract_swagger_route(
+            stack_path, logical_id, body, body_s3_location, None, collector, cwd, Route.HTTP
+        )
 
-    def _extract_cfn_gateway_v2_route(self, resources, logical_id, route_resource, collector):
+    def _extract_cfn_gateway_v2_route(
+        self,
+        stack_path: str,
+        resources: Dict[str, Dict],
+        logical_id: str,
+        route_resource: Dict,
+        collector: ApiCollector,
+    ) -> None:
         """
         Extract APIs from AWS::ApiGatewayV2::Route, and link it with the integration resource to get the lambda
         function.
 
         Parameters
         ----------
+        stack_path : str
+            Path of the stack the resource is located
+
         resources: dict
             All Resource definition, including its properties
 
@@ -274,10 +320,16 @@ class CfnApiProvider(CfnBaseApiProvider):
             function_name=function_name,
             event_type=Route.HTTP,
             payload_format_version=payload_format_version,
+            stack_path=stack_path,
         )
         collector.add_routes(api_id, [routes])
 
-    def resolve_resource_path(self, resources, resource, current_path):
+    def resolve_resource_path(
+        self,
+        resources: Dict[str, Dict],
+        resource: Dict,
+        current_path: str,
+    ) -> str:
         """
         Extract path from the Resource object by going up the tree
 
@@ -294,8 +346,8 @@ class CfnApiProvider(CfnBaseApiProvider):
         """
 
         properties = resource.get("Properties", {})
-        parent_id = properties.get("ParentId")
-        resource_path = properties.get("PathPart")
+        parent_id = cast(str, properties.get("ParentId"))
+        resource_path = cast(str, properties.get("PathPart"))
         parent = resources.get(parent_id)
         if parent:
             return self.resolve_resource_path(resources, parent, "/" + resource_path + current_path)
@@ -305,7 +357,11 @@ class CfnApiProvider(CfnBaseApiProvider):
         return "/" + resource_path + current_path
 
     @staticmethod
-    def _extract_cfn_gateway_v2_stage(resources, stage_resource, collector):
+    def _extract_cfn_gateway_v2_stage(
+        resources: Dict[str, Dict],
+        stage_resource: Dict,
+        collector: ApiCollector,
+    ) -> None:
         """
          Extract the stage from AWS::ApiGatewayV2::Stage resource by reading and adds it to the collector.
          Parameters
@@ -336,7 +392,7 @@ class CfnApiProvider(CfnBaseApiProvider):
         collector.stage_variables = stage_variables
 
     @staticmethod
-    def _get_integration_function_name(integration):
+    def _get_integration_function_name(integration: Dict) -> Optional[str]:
         """
         Tries to parse the Lambda Function name from the Integration defined in the method configuration. Integration
         configuration. We care only about Lambda integrations, which are of type aws_proxy, and ignore the rest.
@@ -345,8 +401,8 @@ class CfnApiProvider(CfnBaseApiProvider):
 
         Parameters
         ----------
-        method_config : str
-            the API gateway route key
+        integration : Dict
+            the integration defined in the method configuration
 
         Returns
         -------
@@ -356,12 +412,15 @@ class CfnApiProvider(CfnBaseApiProvider):
 
         if integration and isinstance(integration, dict):
             # Integration must be "aws_proxy" otherwise we don't care about it
-            return LambdaUri.get_function_name(integration.get("Uri"))
+            uri: str = cast(str, integration.get("Uri"))
+            return LambdaUri.get_function_name(uri)
 
         return None
 
     @staticmethod
-    def _get_route_function_name(resources, integration_target):
+    def _get_route_function_name(
+        resources: Dict[str, Dict], integration_target: str
+    ) -> Tuple[Optional[str], Optional[str]]:
         """
         Look for the APIGateway integration resource based on the input integration_target, then try to parse the
         lambda function from the the integration resource properties.
@@ -396,7 +455,7 @@ class CfnApiProvider(CfnBaseApiProvider):
         return None, None
 
     @staticmethod
-    def _parse_route_key(route_key):
+    def _parse_route_key(route_key: Optional[str]) -> Tuple[str, str]:
         """
         parse the route key, and return the methods && path.
         route key should be in format "Http_method Path" or to equal "$default"
